# History

## 0.2.0 (2019-05-29)

New Python API

### New Features

* New API for ATM usage within Python - [Issue #142](https://github.com/HDI-Project/ATM/issues/142) by
  @pvk-developer and @csala
* Improved Documentation - [Issue #142](https://github.com/HDI-Project/ATM/issues/142) by
  @pvk-developer and @csala
* Code cleanup - [Issue #102](https://github.com/HDI-Project/ATM/issues/102) by
  @csala
* Ensure datasets can be downloaded from S3 - [Issue #137](https://github.com/HDI-Project/ATM/issues/137) by @pvk-developer
* Change to PyMySQL to remove libmysqlclient-dev system dependency - [Issue #136](https://github.com/HDI-Project/ATM/issues/136) by @pvk-developer and @csala

## 0.1.2 (2019-05-07)

REST API and Cluster Management.

### New Features

* REST API Server - Issues [#82](https://github.com/HDI-Project/ATM/issues/82) and
  [#132](https://github.com/HDI-Project/ATM/issues/132) by @RogerTangos, @pvk-developer and @csala
* Add Cluster Management commands to start and stop the server and multiple workers
  as background processes - [Issue #130](https://github.com/HDI-Project/ATM/issues/130) by
  @pvk-developer and @csala
* Add TravisCI and migrate docs to GitHub Pages - [Issue #129](https://github.com/HDI-Project/ATM/issues/129)
  by @pvk-developer

## 0.1.1 (2019-04-02)

First Release on PyPi.

### New Features

* Upgrade to latest BTB.
* New Command Line Interface.

## 0.1.0 (2018-05-04)

* First Release.
